Module music_timer_engine

Module music_timer_engine 

Easy interface for changes in music time.

Structs

MusicTimerEngine
The engine uses all of this crate’s utilities to allow to use of a music performance state system that triggers callbacks. Its aims are to allow for an easy interface for changes in music time.

Traits

MusicTimerState
This trait is used by MusicTimerEngine for callbacks in changes of music time. Invoke it to make the most of the performance engine.