Easy interface for changes in music time.
Structs
- Music
Timer Engine - The engine uses all of this crate’s utilities to allow to use of a music performance state system that triggers callbacks. Its aims are to allow for an easy interface for changes in music time.
Traits
- Music
Timer State - This trait is used by
MusicTimerEnginefor callbacks in changes of music time. Invoke it to make the most of the performance engine.