[][src]Trait music_timer::music_timer_engine::MusicTimerState

pub trait MusicTimerState {
    fn on_beat_interval(&mut self, current_time: &MusicTime);
fn on_beat(&mut self, current_time: &MusicTime);
fn on_bar(&mut self, current_time: &MusicTime); }

This trait is used by MusicTimerEngine for callbacks in changes of music time. Invoke it to make the most of the performance engine.

Required methods

fn on_beat_interval(&mut self, current_time: &MusicTime)

Called when the beat interval changes.

Arguments

  • current_time - The current time at which this callback has been triggered.

fn on_beat(&mut self, current_time: &MusicTime)

Called when the beat changes.

Arguments

  • current_time - The current time at which this callback has been triggered.

fn on_bar(&mut self, current_time: &MusicTime)

Called when the bar changes

Arguments

  • current_time - The current time at which this callback has been triggered.
Loading content...

Implementors

Loading content...